@@ -2,8 +2,7 @@ from __future__ import absolute_import
 # load credentials
 from builtins import str
 import logging
-import utils
-from utils import safe_read_simple_url, safe_get_json
+from utils import safe_read_simple_url, safe_get_json, retrieve_creds, get_gcp_metadata, get_azure_metadata
 
 """
 This is for Elastic group spotinst-agent specific
@@ -115,7 +114,7 @@ def init__configuration(config, cloud_provider, debug=False):
     instance_details = None
     log = logging.getLogger('spotinst-agent')
 
-    creds = utils.retrieve_creds()
+    creds = retrieve_creds()
     authentication_token = creds["token"]
     account_id = creds["account_id"]
 
@@ -153,7 +152,7 @@ def getGcpInstanceMetadata(locator_url, path_params, log):
     response = None
     if locator_url:
         if locator_url.startswith("http://"):
-            response = utils.get_gcp_metadata(locator_url, path_params, log)
+            response = get_gcp_metadata(locator_url, path_params, log)
             response = str(response)
 
         log.debug("found instance id - {}".format(response))
@@ -168,7 +167,7 @@ def getAzureInstanceId(locator_url, log):
     response = None
     if locator_url:
         if locator_url.startswith("http://"):
-            response = utils.get_azure_metadata(locator_url, log)
+            response = get_azure_metadata(locator_url, log)
             response = str(response)
 
         else:
