@@ -10,7 +10,7 @@ import traceback
 
 from scheduler import ThreadedScheduler, method
 from utils import load_class_from_name
-import basemodule
+from basemodule import Module
 
 
 class TaskManager(object):
@@ -155,7 +155,7 @@ class TaskManager(object):
                     # Only attempt to load classes that are infact classes but not the base Module class
                     self.log.debug("Checking " + str(modname) + " Attribute " + str(attrname))
 
-                    if inspect.isclass(attr) and isModule(attr) and attr != basemodule.Module:
+                    if inspect.isclass(attr) and isModule(attr) and attr != Module:
                         # Get class name
                         fqcn = '.'.join([modname, attrname])
                         self.log.info("Module loaded : " + fqcn)
